<?php

namespace FiloBlu\Core\Framework\Model\Mail;

use FiloBlu\Core\Framework\Model\DataSetInterface;

/**
 * Interface MessageInterface
 * @package FiloBlu\Core\Framework\Model\Mail
 */
interface MessageInterface extends DataSetInterface
{
    /** @var string */
    const FROM = 'from';
    /** @var string */
    const TO = 'to';
    /** @var string */
    const STORE_ID = 'store_id';
    /** @var string */
    const REPLY_TO = 'reply_to';
    /** @var string */
    const BCC = 'bcc';
    /** @var string */
    const CC = 'cc';
    /** @var string */
    const EMAIL_TEMPLATE = 'template';
    /** @var string */
    const EMAIL_TEMPLATE_VARIABLES = 'template_variables';
    /** @var string */
    const EMAIL_TEMPLATE_OPTIONS = 'template_options';

    /**
     * @param $replyTo
     * @return MessageInterface
     */
    public function setReplyTo($replyTo): MessageInterface;

    /**
     * @param $bcc
     * @return MessageInterface
     */
    public function setBcc($bcc): MessageInterface;

    /**
     * @param $cc
     * @return MessageInterface
     */
    public function setCc($cc): MessageInterface;

    /**
     * @return MessageInterface
     */
    public function getReplyTo();

    /**
     * @return MessageInterface
     */
    public function getBcc();

    /**
     * @return MessageInterface
     */
    public function getCc();

    /**
     * @param $from
     * @return mixed
     */
    public function setFrom($from): MessageInterface;

    /**
     * @return mixed
     */
    public function getFrom();

    /**
     * @param string|string[] $to
     *
     * @return MessageInterface
     */
    public function setTo($to): MessageInterface;

    /**
     * @param string|string[] $to
     *
     * @return MessageInterface
     */
    public function addTo($to): MessageInterface;

    /**
     * @return array
     */
    public function getTo();

    /**
     * @return int
     */
    public function getStoreId();

    /**
     * @param $storeId
     * @return MessageInterface
     */
    public function setStoreId($storeId): MessageInterface;

    /**
     * @param $template
     * @return mixed
     */
    public function setTemplate($template): MessageInterface;

    /**
     * @return mixed
     */
    public function getTemplate();

    /**
     * @param array $variables
     * @return mixed
     */
    public function setTemplateVariables(array $variables): MessageInterface;

    /**
     * @return mixed
     */
    public function getTemplateVariables();

    /**
     * @param array $options
     * @return mixed
     */
    public function setTemplateOptions(array $options): MessageInterface;

    /**
     * @return array
     */
    public function getTemplateOptions();
}
